@@ -6,7 +6,7 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(ArrayRef Str);
 use namespace::autoclean;
 
-our $VERSION = '2.000';
+our $VERSION = '2.002';
 
 extends qw(
     Locale::TextDomain::OO::Extract::Base::RegexBasedExtractor
@@ -48,18 +48,27 @@ my $comma_rule = qr{ \s* , \s* }xms;
 my $count_rule = qr{ \s* ( [^,)]+ ) \s* }xms;
 my $close_rule = qr{ \s* [,]? \s* ( [^)]* ) [)] }xms;
 
-my $start_rule = qr{ \b N? (?: _ d? c? n? p? x? | d? c? n? p? gettext ) \s* [(] }xms;
+my $start_rule = qr{
+    \b N?
+    (?:
+        # Gettext::Loc, Gettext
+        (?: loc_ | __? ) d? c? n? p? x?
+        # Gettext
+        | d? c? n? p? gettext
+    )
+    \s* [(]
+}xms;
 
 my $rules = [
-    # _
+    # loc_, _, __
     [
-        qr{ \b N? _ ( x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( x? ) \s* [(] \s* }xms,
         $text_rule,
         $close_rule,
     ],
     'or',
     [
-        qr{ \b N? _ ( n x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( n x? ) \s* [(] \s* }xms,
         $singular_rule,
         $comma_rule,
         $plural_rule,
@@ -69,7 +78,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( p x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( p x? ) \s* [(] \s* }xms,
         $context_rule,
         $comma_rule,
         $text_rule,
@@ -77,7 +86,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( np x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( np x? ) \s* [(] \s* }xms,
         $context_rule,
         $comma_rule,
         $singular_rule,
@@ -88,10 +97,10 @@ my $rules = [
         $close_rule,
     ],
 
-    # _d
+    # loc_d, _d, __d
     'or',
     [
-        qr{ \b N? _ ( d x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( d x? ) \s* [(] \s* }xms,
         $domain_rule,
         $comma_rule,
         $text_rule,
@@ -99,7 +108,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( dn x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( dn x? ) \s* [(] \s* }xms,
         $domain_rule,
         $comma_rule,
         $singular_rule,
@@ -111,7 +120,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( dp x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( dp x? ) \s* [(] \s* }xms,
         $domain_rule,
         $comma_rule,
         $context_rule,
@@ -121,7 +130,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( dnp x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( dnp x? ) \s* [(] \s* }xms,
         $domain_rule,
         $comma_rule,
         $context_rule,
@@ -134,10 +143,10 @@ my $rules = [
         $close_rule,
     ],
 
-    # _c
+    # loc_c, _c, __c
     'or',
     [
-        qr{ \b N? _ ( c x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( c x? ) \s* [(] \s* }xms,
         $text_rule,
         $comma_rule,
         $category_rule,
@@ -145,7 +154,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( cn x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( cn x? ) \s* [(] \s* }xms,
         $singular_rule,
         $comma_rule,
         $plural_rule,
@@ -157,7 +166,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( cp x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( cp x? ) \s* [(] \s* }xms,
         $context_rule,
         $comma_rule,
         $text_rule,
@@ -167,7 +176,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( cnp x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( cnp x? ) \s* [(] \s* }xms,
         $context_rule,
         $comma_rule,
         $singular_rule,
@@ -180,10 +189,10 @@ my $rules = [
         $close_rule,
     ],
 
-    # _dc
+    # loc_dc, _dc, __dc
     'or',
     [
-        qr{ \b N? _ ( dc x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( dc x? ) \s* [(] \s* }xms,
         $domain_rule,
         $comma_rule,
         $text_rule,
@@ -193,7 +202,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( dcn x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( dcn x? ) \s* [(] \s* }xms,
         $domain_rule,
         $comma_rule,
         $singular_rule,
@@ -207,7 +216,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( dcp x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( dcp x? ) \s* [(] \s* }xms,
         $domain_rule,
         $comma_rule,
         $context_rule,
@@ -219,7 +228,7 @@ my $rules = [
     ],
     'or',
     [
-        qr{ \b N? _ ( dcnp x? ) \s* [(] \s* }xms,
+        qr{ \b N? (?: loc_ | __? ) ( dcnp x? ) \s* [(] \s* }xms,
         $domain_rule,
         $comma_rule,
         $context_rule,
@@ -556,13 +565,13 @@ __END__
 Locale::TextDomain::OO::Extract::JavaScript
 - Extracts internationalization data from JavaScript code
 
-$Id: JavaScript.pm 518 2014-10-09 14:56:14Z steffenw $
+$Id: JavaScript.pm 561 2014-11-11 16:12:48Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/extract/trunk/lib/Locale/TextDomain/OO/Extract/JavaScript.pm $
 
 =head1 VERSION
 
-2.000
+2.002
 
 =head1 DESCRIPTION
 
@@ -570,6 +579,42 @@ This module extracts internationalization data from JavaScript code.
 
 Implemented Rules:
 
+ loc_('...
+ loc_x('...
+ loc_n('...
+ loc_nx('...
+ loc_p('...
+ loc_px('...
+ loc_np('...
+ loc_npx('...
+
+ loc_d('...
+ loc_dx('...
+ loc_dn('...
+ loc_dnx('...
+ loc_dp('...
+ loc_dpx('...
+ loc_dnp('...
+ loc_dnpx('...
+
+ loc_c('...
+ loc_cx('...
+ loc_cn('...
+ loc_cnx('...
+ loc_cp('...
+ loc_cpx('...
+ loc_cnp('...
+ loc_cnpx('...
+
+ loc_dc('...
+ loc_dcx('...
+ loc_dcn('...
+ loc_dcnx('...
+ loc_dcp('...
+ loc_dcpx('...
+ loc_dcnp('...
+ loc_dcnpx('...
+
  _('...
  _x('...
  _n('...
@@ -606,6 +651,42 @@ Implemented Rules:
  _dcnp('...
  _dcnpx('...
 
+ __('...
+ __x('...
+ __n('...
+ __nx('...
+ __p('...
+ __px('...
+ __np('...
+ __npx('...
+
+ __d('...
+ __dx('...
+ __dn('...
+ __dnx('...
+ __dp('...
+ __dpx('...
+ __dnp('...
+ __dnpx('...
+
+ __c('...
+ __cx('...
+ __cn('...
+ __cnx('...
+ __cp('...
+ __cpx('...
+ __cnp('...
+ __cnpx('...
+
+ __dc('...
+ __dcx('...
+ __dcn('...
+ __dcnx('...
+ __dcp('...
+ __dcpx('...
+ __dcnp('...
+ __dcnpx('...
+
  gettext('...
  ngettext('...
  pgettext('...
@@ -628,7 +709,7 @@ Implemented Rules:
 
 Whitespace is allowed everywhere.
 Quote and escape any text like: C<' text {placeholder} \\ \' ' or " text {placeholder} \\ \" }>
-Also possible all functions with N in front like N_, Ngettext, ... to prepare only.
+Also possible all functions with N in front like Nloc_, N__, Ngettext, ... to prepare only.
 
 =head1 SYNOPSIS
 
@@ -702,7 +783,7 @@ none
 
 L<Locale::TextDoamin::OO|Locale::TextDoamin::OO>
 
-L<http://jsgettext.berlios.de/>
+L<http://sourceforge.net/projects/jsgettext.berlios/>
 
 =head1 AUTHOR
 
